@@ -4,5 +4,6 @@ git clean -dfx \
 	-e .settings \
 	-e .metadata \
 	-e Debug/ \
-	-e examples/tal/arin.tal \
-	-e tmp
+	-e tmp/ \
+	-e sandbox/
+
