@@ -5,13 +5,10 @@
 #ifndef	_GeneralizedTime_H_
 #define	_GeneralizedTime_H_
 
-#include "asn1/asn1c/OCTET_STRING.h"
 #include <sys/stat.h>
 #include <time.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+#include "asn1/asn1c/OCTET_STRING.h"
 
 typedef OCTET_STRING_t GeneralizedTime_t;  /* Implemented via OCTET STRING */
 
@@ -22,19 +19,20 @@ asn_struct_print_f GeneralizedTime_print;
 asn_struct_compare_f GeneralizedTime_compare;
 asn_constr_check_f GeneralizedTime_constraint;
 der_type_encoder_f GeneralizedTime_encode_der;
+json_type_encoder_f GeneralizedTime_encode_json;
 xer_type_encoder_f GeneralizedTime_encode_xer;
-asn_random_fill_f  GeneralizedTime_random_fill;
 
 #define GeneralizedTime_free           OCTET_STRING_free
 #define GeneralizedTime_decode_ber     OCTET_STRING_decode_ber
-#define GeneralizedTime_decode_xer     OCTET_STRING_decode_xer_utf8
-#define GeneralizedTime_decode_uper    OCTET_STRING_decode_uper
-#define GeneralizedTime_encode_uper    OCTET_STRING_encode_uper
 
 /***********************
  * Some handy helpers. *
  ***********************/
 
+#define ASN_TM_STR_MAXLEN 21
+
+int asn_tm2str(struct tm *tm, char *str);
+
 /*
  * Convert a GeneralizedTime structure into time_t
  * and optionally into struct tm.
@@ -70,8 +68,4 @@ GeneralizedTime_t *asn_time2GT(GeneralizedTime_t *_optional_gt,
 GeneralizedTime_t *asn_time2GT_frac(GeneralizedTime_t *_optional_gt,
 	const struct tm *, int frac_value, int frac_digits);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif	/* _GeneralizedTime_H_ */
