@@ -7,10 +7,6 @@
 
 #include "asn1/asn1c/OCTET_STRING.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 typedef OCTET_STRING_t IA5String_t;  /* Implemented via OCTET STRING */
 
 /*
@@ -26,13 +22,6 @@ asn_constr_check_f IA5String_constraint;
 #define IA5String_compare       OCTET_STRING_compare
 #define IA5String_decode_ber    OCTET_STRING_decode_ber
 #define IA5String_encode_der    OCTET_STRING_encode_der
-#define IA5String_decode_xer    OCTET_STRING_decode_xer_utf8
 #define IA5String_encode_xer    OCTET_STRING_encode_xer_utf8
-#define IA5String_decode_uper   OCTET_STRING_decode_uper
-#define IA5String_encode_uper   OCTET_STRING_encode_uper
-
-#ifdef __cplusplus
-}
-#endif
 
 #endif	/* _IA5String_H_ */
