@@ -5,13 +5,10 @@
 #ifndef	_UTCTime_H_
 #define	_UTCTime_H_
 
-#include "asn1/asn1c/OCTET_STRING.h"
 #include <sys/stat.h>
 #include <time.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+#include "asn1/asn1c/OCTET_STRING.h"
 
 typedef OCTET_STRING_t UTCTime_t;  /* Implemented via OCTET STRING */
 
@@ -21,15 +18,12 @@ extern asn_TYPE_operation_t asn_OP_UTCTime;
 asn_struct_print_f UTCTime_print;
 asn_struct_compare_f UTCTime_compare;
 asn_constr_check_f UTCTime_constraint;
+json_type_encoder_f UTCTime_encode_json;
 xer_type_encoder_f UTCTime_encode_xer;
-asn_random_fill_f  UTCTime_random_fill;
 
 #define UTCTime_free         OCTET_STRING_free
 #define UTCTime_decode_ber   OCTET_STRING_decode_ber
 #define UTCTime_encode_der   OCTET_STRING_encode_der
-#define UTCTime_decode_xer   OCTET_STRING_decode_xer_utf8
-#define UTCTime_decode_uper  OCTET_STRING_decode_uper
-#define UTCTime_encode_uper  OCTET_STRING_encode_uper
 
 /***********************
  * Some handy helpers. *
@@ -43,8 +37,4 @@ time_t asn_UT2time(const UTCTime_t *, struct tm *_optional_tm4fill);
 /* See asn_time2GT() in GeneralizedTime.h */
 UTCTime_t *asn_time2UT(UTCTime_t *__opt_ut, const struct tm *);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif	/* _UTCTime_H_ */
