@@ -2,10 +2,12 @@
  * Copyright (c) 2003, 2004 Lev Walkin <vlm@lionet.info>. All rights reserved.
  * Redistribution and modifications are permitted subject to BSD license.
  */
-#include "asn1/asn1c/asn_internal.h"
 #include "asn1/asn1c/asn_SET_OF.h"
+
 #include <errno.h>
 
+#include "asn1/asn1c/asn_internal.h"
+
 /*
  * Add another element into the set.
  */
@@ -13,7 +15,7 @@ int
 asn_set_add(void *asn_set_of_x, void *ptr) {
 	asn_anonymous_set_ *as = _A_SET_FROM_VOID(asn_set_of_x);
 
-	if(as == 0 || ptr == 0) {
+	if(as == NULL || ptr == NULL) {
 		errno = EINVAL;		/* Invalid arguments */
 		return -1;
 	}
@@ -51,7 +53,7 @@ asn_set_del(void *asn_set_of_x, int number, int _do_free) {
 		if(_do_free && as->free) {
 			ptr = as->array[number];
 		} else {
-			ptr = 0;
+			ptr = NULL;
 		}
 
 		as->array[number] = as->array[--as->count];
@@ -78,7 +80,7 @@ asn_set_empty(void *asn_set_of_x) {
 					as->free(as->array[as->count]);
 			}
 			FREEMEM(as->array);
-			as->array = 0;
+			as->array = NULL;
 		}
 		as->count = 0;
 		as->size = 0;
