@@ -3,10 +3,9 @@
 
 /* Some wrappers for asn1/asn1c/ContentInfo.h. */
 
-#include "types/uri.h"
 #include "asn1/asn1c/ContentInfo.h"
 
-int content_info_load(struct rpki_uri *, struct ContentInfo **);
+int content_info_load(char const *, struct ContentInfo **);
 void content_info_free(struct ContentInfo *);
 
 #endif /* SRC_CONTENT_INFO_H_ */
