@@ -1,6 +1,8 @@
 #include "asn1/oid.h"
 
 #include <errno.h>
+#include <stdlib.h>
+#include <string.h>
 
 #include "alloc.h"
 #include "log.h"
