@@ -3,6 +3,7 @@
 #include <errno.h>
 #include <getopt.h>
 #include <libxml/xmlreader.h>
+#include <microhttpd.h>
 #include <openssl/opensslv.h>
 #include <syslog.h>
 
@@ -75,6 +76,10 @@ struct rpki_config {
 		unsigned int deltas_lifetime;
 	} server;
 
+	struct {
+		unsigned int port;
+	} prometheus;
+
 	struct {
 		/* Enables the protocol */
 		bool enabled;
@@ -125,6 +130,8 @@ struct rpki_config {
 		curl_off_t max_file_size;
 		/* Directory where CA certs to verify peers are found */
 		char *ca_path;
+		/* See CURLOPT_PROXY */
+		char *proxy;
 	} http;
 
 	struct {
@@ -331,7 +338,7 @@ static const struct option_field options[] = {
 	}, {
 		.id = 5001,
 		.name = "server.port",
-		.type = &gt_string,
+		.type = &gt_service,
 		.offset = offsetof(struct rpki_config, server.port),
 		.doc = "Default port to which RTR server addresses will bind itself to. Can be a string, in which case a number will be resolved. If all of the addresses have a port, this value isn't utilized.",
 		.json_null_allowed = false,
@@ -420,6 +427,19 @@ static const struct option_field options[] = {
 		.max = UINT_MAX,
 	},
 
+	/* Prometheus fields */
+	{
+		.id = 14000,
+		.name = "prometheus.port",
+		.type = &gt_uint,
+		.offset = offsetof(struct rpki_config, prometheus.port),
+		.doc = "Port to bind the Prometheus server to. "
+		    "Prometheus requires this value and 'server' mode to start. "
+		    "Unlike server.port, prometheus.port will not be resolved.",
+		.min = 0,
+		.max = 0xFFFF,
+	},
+
 	/* RSYNC fields */
 	{
 		.id = 3000,
@@ -590,7 +610,15 @@ static const struct option_field options[] = {
 		.offset = offsetof(struct rpki_config, http.ca_path),
 		.doc = "Directory where CA certificates are found, used to verify the peer",
 		.arg_doc = "<directory>",
-		.json_null_allowed = false,
+		.json_null_allowed = true,
+	}, {
+		.id = 9013,
+		.name = "http.proxy",
+		.type = &gt_string,
+		.offset = offsetof(struct rpki_config, http.proxy),
+		.doc = "Name of proxy to use",
+		.arg_doc = "<URI>",
+		.json_null_allowed = true,
 	},
 
 	/* Logging fields */
@@ -895,10 +923,13 @@ print_config(void)
 	struct option_field const *opt;
 
 	pr_op_info(PACKAGE_STRING);
-	pr_op_info("  libcrypto: " OPENSSL_VERSION_TEXT);
-	pr_op_info("  jansson:   " JANSSON_VERSION);
-	pr_op_info("  libcurl:   " LIBCURL_VERSION);
-	pr_op_info("  libxml:    " LIBXML_DOTTED_VERSION);
+	pr_op_info("  libcrypto:     " OPENSSL_VERSION_TEXT);
+	pr_op_info("  jansson:       " JANSSON_VERSION);
+	pr_op_info("  libcurl:       " LIBCURL_VERSION);
+	pr_op_info("  libxml:        " LIBXML_DOTTED_VERSION);
+	pr_op_info("  libmicrohttpd: %x.%x.%x-%x",
+	    MHD_VERSION >> 24, (MHD_VERSION >> 16) & 0xFF,
+	    (MHD_VERSION >> 8) & 0xFF, MHD_VERSION & 0xFF);
 
 	pr_op_info("Configuration {");
 
@@ -955,6 +986,8 @@ set_default_values(void)
 	rpki_config.server.interval.expire = 7200;
 	rpki_config.server.deltas_lifetime = 2;
 
+	rpki_config.prometheus.port = 0;
+
 	rpki_config.rsync.enabled = true;
 	rpki_config.rsync.priority = 50;
 	rpki_config.rsync.strategy = pstrdup("<deprecated>");
@@ -980,6 +1013,7 @@ set_default_values(void)
 	rpki_config.http.low_speed_time = 10;
 	rpki_config.http.max_file_size = 2000000000;
 	rpki_config.http.ca_path = NULL; /* Use system default */
+	rpki_config.http.proxy = NULL;
 
 	rpki_config.log.enabled = true;
 	rpki_config.log.tag = NULL;
@@ -1013,6 +1047,8 @@ set_default_values(void)
 static int
 validate_config(void)
 {
+	char const *proxy;
+
 	if (rpki_config.mode == PRINT_FILE)
 		return 0;
 
@@ -1040,6 +1076,14 @@ validate_config(void)
 	if (rpki_config.slurm != NULL && !valid_file_or_dir(rpki_config.slurm, true))
 		return pr_op_err("Invalid slurm location.");
 
+	if (rpki_config.http.proxy == NULL) {
+		proxy = curl_getenv("https_proxy");
+		if (proxy == NULL)
+			proxy = curl_getenv("HTTPS_PROXY");
+		if (proxy != NULL && proxy[0] != '\0')
+			rpki_config.http.proxy = pstrdup(proxy);
+	}
+
 	return 0;
 }
 
@@ -1228,6 +1272,12 @@ config_get_deltas_lifetime(void)
 	return rpki_config.server.deltas_lifetime;
 }
 
+unsigned int
+config_get_prometheus_port(void)
+{
+	return rpki_config.prometheus.port;
+}
+
 char const *
 config_get_slurm(void)
 {
@@ -1402,6 +1452,12 @@ config_get_http_retry_interval(void)
 	return rpki_config.http.retry.interval;
 }
 
+char const *
+config_get_http_proxy(void)
+{
+	return rpki_config.http.proxy;
+}
+
 char const *
 config_get_http_user_agent(void)
 {
