@@ -1,6 +1,7 @@
 #include "config/str.h"
 
 #include <getopt.h>
+#include <string.h>
 
 #include "alloc.h"
 #include "log.h"
@@ -80,6 +81,43 @@ const struct global_type gt_string = {
 	.arg_doc = "<string>",
 };
 
+static int
+service_parse_json(struct option_field const *opt, json_t *json, void *result)
+{
+	json_int_t intval;
+	char *strval;
+	int written;
+
+	if (json_is_integer(json)) {
+		intval = json_integer_value(json);
+		if (intval < 1 || 65535 < intval) {
+			return pr_op_err("'%s' is out of range (1-65535).",
+			    opt->name);
+		}
+
+		strval = pmalloc(6);
+		written = snprintf(strval, 6, "%" JSON_INTEGER_FORMAT, intval);
+		if (written < 0 || 6 <= written)
+			return pr_op_err("Cannot convert '%s' to string: snprintf returned %d",
+			    opt->name, written);
+
+		DEREFERENCE(result) = strval;
+		return 0;
+	}
+
+	return string_parse_json(opt, json, result);
+}
+
+const struct global_type gt_service = {
+	.has_arg = required_argument,
+	.size = sizeof(char *),
+	.print = string_print,
+	.parse.argv = string_parse_argv,
+	.parse.json = service_parse_json,
+	.free = string_free,
+	.arg_doc = "<port>",
+};
+
 /**
  * *result must not be freed nor long-term stored.
  */
