@@ -4,8 +4,6 @@
 #include <openssl/obj_mac.h>
 #include <openssl/objects.h>
 
-#include "cert_stack.h"
-#include "common.h"
 #include "crypto/hash.h"
 #include "json_util.h"
 #include "libcrypto_util.h"
@@ -1005,6 +1003,10 @@ handle_aki(void *ext, void *arg)
 	AUTHORITY_KEYID *aki = ext;
 	X509 *parent;
 
+	if (aki->keyid == NULL) {
+		return pr_val_err("%s extension lacks a keyIdentifier.",
+		    ext_aki()->name);
+	}
 	if (aki->issuer != NULL) {
 		return pr_val_err("%s extension contains an authorityCertIssuer.",
 		    ext_aki()->name);
