@@ -10,6 +10,10 @@
 enum incidence_id {
 	INID_HASHALG_HAS_PARAMS,
 	INID_OBJ_NOT_DER,
+	INID_MFT_FILE_NOT_FOUND,
+	INID_MFT_FILE_HASH_NOT_MATCH,
+	INID_MFT_STALE,
+	INID_CRL_STALE,
 
 	__INID_MAX,
 };
