@@ -8,8 +8,9 @@
  */
 
 #include "as_number.h"
-#include "rtr/db/deltas_array.h"
 #include "types/address.h"
+#include "types/delta.h"
+#include "types/serial.h"
 
 int vrps_init(void);
 void vrps_destroy(void);
