@@ -3,9 +3,9 @@
 #include <errno.h>
 
 #include "log.h"
+#include "rtr/db/vrps.h"
 #include "rtr/err_pdu.h"
 #include "rtr/pdu_sender.h"
-#include "rtr/pdu_stream.h"
 
 struct send_delta_args {
 	int fd;
