@@ -8,11 +8,13 @@
 #include "line_file.c"
 #include "mock.c"
 #include "data_structure/path_builder.c"
+#include "rrdp.h"
 #include "types/uri.c"
 #include "crypto/base64.c"
 
 /* Mocks */
 
+MOCK(config_get_local_repository, char const *, "tmp/tal", void)
 MOCK_ABORT_VOID(cache_setup, void)
 MOCK(cache_create, struct rpki_cache *, NULL, char const *tal)
 MOCK_VOID(cache_destroy, struct rpki_cache *cache)
